@@ -24,6 +24,7 @@ from ._runner import (
 )
 from ._terminal import get_terminal_width
 from ._text import inline_text, lazy_str, pluralize
+from ._tomlconfig import TomlConfigFile
 
 __all__ = [
     # _asciitable
@@ -67,7 +68,9 @@ __all__ = [
     "pluralize",
     "inline_text",
     "lazy_str",
+    # _tomlconfig
+    "TomlConfigFile",
     # global
     "path",
 ]
-__version__ = "0.1.0"
+__version__ = "0.2.1"
